mod bot;
mod config;
mod db;
mod img;

use actix_cors::Cors;
use actix_web::{App, HttpServer};
use bot::init::start_bot;
use config::parse_local_config;

#[tokio::main] // or #[actix_web::main]
async fn main() -> std::io::Result<()> {
    let config = parse_local_config();
    let port = config.port;
    match db::init::init_db(config.persistence.clone()).await {
        Ok(_) => {}
        Err(e) => {
            println!("Error initializing database: {}", e);
            return Ok(());
        }
    }
    start_bot(config.clone());
    HttpServer::new(|| {
        let cors = Cors::default()
            .allow_any_header()
            .allow_any_method()
            .allow_any_origin();
        App::new().wrap(cors)
    })
    .bind(("0.0.0.0", port))?
    .run()
    .await?;
    Ok(())
}
